#!/usr/local/bin/perl -w

=head1 NAME

p4.t - testing of vcp p4 i/o

=cut

use strict ;

use Carp ;
use File::Path ;
use File::Spec ;
use POSIX ':sys_wait_h' ;
use Test ;
use VCP::TestUtils ;

# use eq_or_diff from Test::Differences if available,
# else just use ok.
eval "use Test::Differences";
sub ok_or_diff {
   goto &eq_or_diff if defined &eq_or_diff;
   goto &Test::ok;
}


my @vcp = vcp_cmd ;

my $t = -d 't' ? 't/' : '' ;

my $p4root_1  = "${t}p4root_1";
my $p4state_1 = "${t}p4state_1";
my $p4_rev_root = "//depot/foo/";
my $p4_spec = "p4:revml2p4\@$p4root_1:$p4_rev_root";

my @tests = (
## copy p4root_0 to p4root_1
sub {
   my $p4root_0  = "${t}p4root_0";
   my $p4state_0 = "${t}p4state_0";
   rmtree [ grep -e, $p4root_1, $p4state_1 ];
   copy_dir_tree $p4root_0, $p4root_1;
   copy_dir_tree $p4state_0, $p4state_1;
   ok 1;
},

## revml -> p4 
sub {
   my $infile  = $t . "test-p4-in-1.revml" ;
   ok run [ @vcp, "revml:$infile", $p4_spec,
      "--run-p4d", "--state-location=$p4state_1"
   ], \undef;
},


## slurp revml files and analyze with regexps to count number of
## unique named files and the highest change number for each file,
## then use the p4 files command line client to see if the repository
## really contains all that.

## detailed analysis of this import is left to 91p42revml.t             

sub {
   my $infile0  = $t . "test-p4-in-0.revml" ;
   my $infile1  = $t . "test-p4-in-1.revml" ;

   my $p4_options = launch_p4d "p4_", { 
      repo_dir      => "${t}p4root_1",
   } ;

   my $revs1 = parse_files_and_revids_from_p4_files $p4_rev_root, $p4_options, "//..." ;
   my $revs2 = parse_files_and_revids_from_revml $infile0, $infile1 ;

   ok_or_diff $revs1, $revs2;
},

) ;  # end @tests



plan tests => scalar @tests ;

my $p4d_borken = p4d_borken ;

my $why_skip ;
$why_skip .= "p4 command not found\n"  unless ( `p4 -V`  || 0 ) =~ /^Perforce/ ;
$why_skip .= "$p4d_borken\n"           if $p4d_borken ;

$why_skip ? skip( $why_skip, '' ) : $_->() for @tests ;
